package com.agilecontrol.nea.core.control.web.binhandler;

import com.agilecontrol.nea.core.control.util.FileDownload;
import com.agilecontrol.nea.core.control.web.UserWebImpl;
import com.agilecontrol.nea.core.control.web.binhandler.BinaryHandler;
import com.agilecontrol.nea.core.report.ReportUtils;
import com.agilecontrol.nea.core.util.ConfigValues;
import java.io.File;
import java.io.PrintWriter;
import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class Download implements BinaryHandler {

   private static final Logger log = LoggerFactory.getLogger(Download.class);
   private static final String CONTENT_TYPE = "text/plain; charset=UTF-8";
   private static final String DOWNLOAD_TYPE = "application/octetstream; charset=GBK";
   private static final String[] TEXT_TYPE = new String[]{"html", "htm", "csv", "txt", "log"};
   private static final String[] EXT = new String[]{"xls", "doc", "pdf", "zip", "db", "xlsx"};
   private static final String[] EXT_CONTENT_TYPE = new String[]{"application/vnd.ms-excel", "application/vnd.ms-word", "application/pdf", "application/zip", "application/db", "application/vnd.ms-excel"};


   private boolean isTextType(String fileName) {
      String ext = fileName.substring(fileName.lastIndexOf(".") + 1).toLowerCase();

      for(int i = 0; i < TEXT_TYPE.length; ++i) {
         if(ext.equalsIgnoreCase(TEXT_TYPE[i])) {
            return true;
         }
      }

      return false;
   }

   public void process(HttpServletRequest request, HttpServletResponse response) throws Exception {
      String filePath = request.getParameter("filename");
      boolean deleteFile = false;
      if(filePath == null) {
         String out = request.getPathInfo();
         int name = out.indexOf(47, 1);
         if(name > 0) {
            filePath = out.substring(name + 1);
         }
      }

      if(filePath != null && !filePath.trim().equals("")) {
         filePath = filePath.trim();
         ReportUtils out1 = new ReportUtils(request);
         String name1 = out1.getUserName();
         UserWebImpl userWeb = out1.getUser();
         boolean isRoot = userWeb.isPermissionEnabled("WEBSQL_LIST", 3);
         File file = new File(filePath);
         if(file.isAbsolute()) {
            if(!isRoot && !ConfigValues.EXCEL_PERMISSON) {
               file = null;
            }
         } else if((filePath.contains("..") || filePath.contains("/") || filePath.contains("\\")) && (!ConfigValues.get("portal.skip_root_download", false) || !userWeb.isAdmin())) {
            log.warn("download with relative path: " + filePath);
            file = null;
         } else {
            file = new File(out1.getExportRootPath() + File.separator + out1.getUser().getClientDomain() + File.separator + userWeb.getUserId() + File.separator + filePath);
         }

         if(file != null && !isRoot && !ConfigValues.EXCEL_PERMISSON) {
            File fileDownload = new File(out1.getExportRootPath() + File.separator + out1.getUser().getClientDomain() + File.separator + userWeb.getUserId());
            if(!file.getParentFile().getAbsolutePath().startsWith(fileDownload.getAbsolutePath())) {
               file = null;
            }
         }

         if(file != null && file.exists() && file.isFile()) {
            FileDownload fileDownload1 = new FileDownload();
            fileDownload1.processRequest(request, response, true, file, new String[0]);
            if(deleteFile) {
               try {
                  if(!file.delete()) {
                     log.debug("Fail to delete file:" + file.getAbsolutePath());
                  }
               } catch (Throwable var12) {
                  log.error("Fail to delete file " + file.getAbsolutePath() + ":" + var12);
               }
            }

            return;
         }

         log.warn("Could not load file:" + filePath);
      }

      response.setContentType("text/plain; charset=UTF-8");
      PrintWriter out2 = response.getWriter();
      out2.println("文件不存在,或者文件不可读，或者没有指定文件名");
   }

   public void init(ServletContext context) {
   }

}
